import { AutodiscoverRedirectionUrlValidationCallback } from "./AutodiscoverServiceDelegates";
import { DomainSettingName } from "../Enumerations/DomainSettingName";
import { ExchangeVersion } from "../Enumerations/ExchangeVersion";
import { GetDomainSettingsResponse } from "./Responses/GetDomainSettingsResponse";
import { GetDomainSettingsResponseCollection } from "./Responses/GetDomainSettingsResponseCollection";
import { GetUserSettingsResponse } from "./Responses/GetUserSettingsResponse";
import { GetUserSettingsResponseCollection } from "./Responses/GetUserSettingsResponseCollection";
import { IRefParam } from "../Interfaces/IRefParam";
import { Uri } from "../Uri";
import { UserSettingName } from "../Enumerations/UserSettingName";
import { ExchangeServiceBase } from "../Core/ExchangeServiceBase";
/**
 * Represents a binding to the Exchange Autodiscover Service.
 * @sealed
 */
export declare class AutodiscoverService extends ExchangeServiceBase {
    /**
     * Autodiscover legacy path
     *
     * @static
     */
    private static AutodiscoverLegacyPath;
    /**
     * Autodiscover legacy Url with protocol fill-in
     *
     * @static
     */
    private static AutodiscoverLegacyUrl;
    /**
     * Autodiscover legacy HTTPS Url
     *
     * @static
     */
    private static AutodiscoverLegacyHttpsUrl;
    /**
     * Autodiscover legacy HTTP Url
     *
     * @static
     */
    private static AutodiscoverLegacyHttpUrl;
    /**
     * Autodiscover SOAP HTTPS Url
     *
     * @static
     */
    private static AutodiscoverSoapHttpsUrl;
    /**
     * Autodiscover SOAP WS-Security HTTPS Url
     *
     * @static
     */
    private static AutodiscoverSoapWsSecurityHttpsUrl;
    /**
     * Autodiscover SOAP WS-Security symmetrickey HTTPS Url
     *
     * @static
     */
    private static AutodiscoverSoapWsSecuritySymmetricKeyHttpsUrl;
    /**
     * Autodiscover SOAP WS-Security x509cert HTTPS Url
     *
     * @static
     */
    private static AutodiscoverSoapWsSecurityX509CertHttpsUrl;
    /**
     * Autodiscover request namespace
     *
     * @static
     */
    private static AutodiscoverRequestNamespace;
    /**
     * Legacy path regular expression.
     *
     * @static
     */
    private static readonly LegacyPathRegex;
    /**
     * Maximum number of Url (or address) redirections that will be followed by an Autodiscover call
     *
     * @static
     */
    static AutodiscoverMaxRedirections: number;
    /**
     * HTTP header indicating that SOAP Autodiscover service is enabled.
     *
     * @static
     */
    private static AutodiscoverSoapEnabledHeaderName;
    /**
     * HTTP header indicating that WS-Security Autodiscover service is enabled.
     *
     * @static
     */
    private static AutodiscoverWsSecurityEnabledHeaderName;
    /**
     * HTTP header indicating that WS-Security/SymmetricKey Autodiscover service is enabled.
     *
     * @static
     */
    private static AutodiscoverWsSecuritySymmetricKeyEnabledHeaderName;
    /**
     * HTTP header indicating that WS-Security/X509Cert Autodiscover service is enabled.
     *
     * @static
     */
    private static AutodiscoverWsSecurityX509CertEnabledHeaderName;
    /**
     * HTTP header indicating that OAuth Autodiscover service is enabled.
     *
     * @static
     */
    private static AutodiscoverOAuthEnabledHeaderName;
    /**
     * Minimum request version for Autodiscover SOAP service.
     *
     * @static
     */
    private static MinimumRequestVersionForAutoDiscoverSoapService;
    private static o365AutodiscoverUrl;
    /**
     *  Set Autodiscover hard coded url for Office 365, useful in GCC and O365 in China. This is also helpful if O365 need changing url for some reason (beta testing, transition to different url), no need to update lib
     *
     * @static
     * @type {string}
     */
    static get Office365AutodiscoverUrl(): string;
    static set Office365AutodiscoverUrl(value: string);
    private static o365AutodiscoverRedirectHeader;
    /**
     *  Set Autodiscover hard coded check for header when it is auto redirected (skip 302 and follow the redirect in lib, likely browsers)
     *
     * @static
     * @type {string}
     */
    static get Office365AutodiscoverRedirectHeader(): string;
    static set Office365AutodiscoverRedirectHeader(value: string);
    private static o365AutodiscoverRedirectHeaderValue;
    /**
     *  Set Autodiscover hard coded check for header value when it is auto redirected (skip 302 and follow the redirect in lib, likely browsers)
     *
     * @static
     * @type {string}
     */
    static get Office365AutodiscoverRedirectHeaderValue(): string;
    static set Office365AutodiscoverRedirectHeaderValue(value: string);
    private domain;
    private url;
    private isExternal;
    private redirectionUrlValidationCallback;
    private dnsClient;
    private dnsServerAddress;
    private enableScpLookup;
    get Domain(): string;
    set Domain(value: string);
    get Url(): Uri;
    set Url(value: Uri);
    get IsExternal(): boolean | null;
    set IsExternal(value: boolean | null);
    get RedirectionUrlValidationCallback(): AutodiscoverRedirectionUrlValidationCallback;
    set RedirectionUrlValidationCallback(value: AutodiscoverRedirectionUrlValidationCallback);
    get DnsServerAddress(): any;
    set DnsServerAddress(value: any);
    get EnableScpLookup(): boolean;
    set EnableScpLookup(value: boolean);
    /**
     * Initializes a new instance of the **AutodiscoverService** class.
     */
    constructor();
    /**
     * Initializes a new instance of the **AutodiscoverService** class.
     *
     * @param   {ExchangeVersion}   requestedServerVersion   The requested server version.
     */
    constructor(requestedServerVersion: ExchangeVersion);
    /**
     * Initializes a new instance of the **AutodiscoverService** class.
     *
     * @param   {string}    domain  The domain that will be used to determine the URL of the service.
     */
    constructor(domain: string);
    /**
     * Initializes a new instance of the **AutodiscoverService** class.
     *
     * @param   {Uri}               url                      The URL of the service.
     * @param   {string}            domain                   The domain that will be used to determine the URL of the service.
     * @param   {ExchangeVersion}   requestedServerVersion   The requested server version.
     */
    constructor(domain: string, requestedServerVersion: ExchangeVersion);
    /**
     * Initializes a new instance of the **AutodiscoverService** class.
     *
     * @param   {Uri}   url The URL of the service.
     */
    constructor(url: Uri);
    /**
     * Initializes a new instance of the **AutodiscoverService** class.
     *
     * @param   {Uri}               url                      The URL of the service.
     * @param   {ExchangeVersion}   requestedServerVersion   The requested server version.
     */
    constructor(url: Uri, requestedServerVersion: ExchangeVersion);
    /**
     * Calls the redirection URL validation callback.
     *
     * @remark  If the redirection URL validation callback is null, use the default callback which does not allow following any redirections.
     * @param   {string}    redirectionUrl   The redirection URL.
     * @return  {boolean}   True if redirection should be followed.
     */
    private CallRedirectionUrlValidationCallback;
    /**
     * Default implementation of AutodiscoverRedirectionUrlValidationCallback. Always returns true indicating that the URL can be used.
    *
    * @param   {string}     redirectionUrl   The redirection URL.
    * @return  {boolean}    Returns true.
    */
    private DefaultAutodiscoverRedirectionUrlValidationCallback;
    /**
     * Defaults the get autodiscover service urls for domain.
     *
     * @param   {string}    domainName   Name of the domain.
     * @return  {string[]}  [description]
     */
    private DefaultGetScpUrlsForDomain;
    /**
     * Disables SCP lookup if duplicate email address redirection.
     *
     * @param   {string}    emailAddress                The email address to use.
     * @param   {string[]}  redirectionEmailAddresses   The list of prior redirection email addresses.
     */
    DisableScpLookupIfDuplicateRedirection(emailAddress: string, redirectionEmailAddresses: string[]): void;
    /**
     * Gets the autodiscover endpoint URL.
     *
     * @param   {string}   host   The host.
     * @return  {Promise<Uri>}  [description]
     */
    private GetAutodiscoverEndpointUrl;
    /**
     * Retrieves the specified settings for a set of domains.
     *
     * @param   {string[]}                  domains             The SMTP addresses of the domains.
     * @param   {ExchangeVersion}           requestedVersion    Requested version of the Exchange service.
     * @param   {...DomainSettingName[]}    domainSettingNames  The domain setting names.
     * @return  {Promise<GetDomainSettingsResponseCollection>}  A GetDomainSettingsResponseCollection object containing the responses for each individual domain.
     */
    GetDomainSettings(domains: string[], requestedVersion: ExchangeVersion, ...domainSettingNames: DomainSettingName[]): Promise<GetDomainSettingsResponseCollection>;
    /**
     * Retrieves the specified settings for a domain.
     *
     * @param   {string}                    domain               The domain.
     * @param   {ExchangeVersion}           requestedVersion     Requested version of the Exchange service.
     * @param   {...DomainSettingName[]}    domainSettingNames   The domain setting names.
     * @return  {Promise<GetDomainSettingsResponse>}  A DomainResponse object containing the requested settings for the specified domain.
     */
    GetDomainSettings(domain: string, requestedVersion: ExchangeVersion, ...domainSettingNames: DomainSettingName[]): Promise<GetDomainSettingsResponse>;
    /**
     * Gets the endpoints from HTTP web response.
     *
     * @param   {XMLHttpRequest}   response   The response.
     * @return  {AutodiscoverEndpoints}              Endpoints enabled.
     */
    private GetEndpointsFromHttpWebResponse;
    /**
     * Gets a redirection URL to an SSL-enabled Autodiscover service from the standard non-SSL Autodiscover URL.
     *
     * @param   {string}   domainName   The name of the domain to call Autodiscover on.
     * @return  {Promise<Uri>}                A valid SSL-enabled redirection URL. (May be null).
     */
    private GetRedirectUrl;
    /**
     * Gets user or domain settings using Autodiscover SOAP service.
     *
     * @typeparam {TGetSettingsResponseCollection}  Type of response collection to return.
     * @typeparam {TSettingName}                    Type of setting name.
     *
     * @param   {string[]}                                                          identities          Either the domains or the SMTP addresses of the users.
     * @param   {settings: TSettingName[]}                                          settings            The settings.
     * @param   {ExchangeVersion}                                                   requestedVersion    Requested version of the Exchange service.
     * @param   {GetSettingsMethod<TGetSettingsResponseCollection, TSettingName>}   getSettingsMethod   The method to use.
     * @param   {() => string}                                                      getDomainMethod     The method to calculate the domain value.
     * @return  {Promise<TGetSettingsResponseCollection>}                           [description]
     */
    private GetSettings;
    /**
     * Retrieves the specified settings for single SMTP address.
     * @remarks This method handles will run the entire Autodiscover "discovery" algorithm and will follow address and URL redirections.
     * @param   {string}   userSmtpAddress    The SMTP addresses of the user.
     * @param   {UserSettingName[]}   userSettingNames   The user setting names.
     * @return  {Promise<GetUserSettingsResponse>} A UserResponse object containing the requested settings for the specified user.
     */
    GetUserSettings(userSmtpAddress: string, userSettingNames: UserSettingName[]): Promise<GetUserSettingsResponse>;
    /**
     * Retrieves the specified settings for a set of users.
     *
     * @param   {string[]}              userSmtpAddresses   The SMTP addresses of the users.
     * @param   {...UserSettingName[]}  userSettingNames    The user setting names.
     * @return  {Promise<GetUserSettingsResponseCollection>}    A GetUserSettingsResponseCollection object containing the responses for each individual user.
     */
    GetUsersSettings(userSmtpAddresses: string[], ...userSettingNames: UserSettingName[]): Promise<GetUserSettingsResponseCollection>;
    /**
     * Gets settings for one or more domains.
     *
     * @param   {string[]}              domains            The domains.
     * @param   {DomainSettingName[]}   settings           The settings.
     * @param   {ExchangeVersion}       requestedVersion   Requested version of the Exchange service.
     * @param   {IRefParam<Uri>}        autodiscoverUrl    The autodiscover URL.
     * @return  {AutodiscoverService}   GetDomainSettingsResponse collection.
     */
    private InternalGetDomainSettings;
    private InternalGetLegacyUserSettings;
    private InternalGetLegacyUserSettingsPrivate;
    /**
     * Gets settings for one or more users.
     *
     * @param   {string[]}            smtpAddresses      The SMTP addresses of the users.
     * @param   {UserSettingName[]}   settings           The settings.
     * @param   {ExchangeVersion}     requestedVersion   Requested version of the Exchange service.
     * @param   {IRefParam<Uri>}      autodiscoverUrl    The autodiscover URL.
     * @return  {Promise<GetUserSettingsResponseCollection>}                      GetUserSettingsResponse collection.
     */
    private InternalGetUserSettings;
    ProcessHttpErrorResponse(httpWebResponse: XMLHttpRequest, webException: any): any;
    TraceResponse(response: XMLHttpRequest, memoryStream: any): any;
    /**
     * Tries the get Autodiscover Service endpoint URL.
     *
     * @param   {string}          host   The host.
     * @param   {IOutParam<Uri>}  url    The URL.
     * @return  {Promise<boolean>}         [description]
     */
    private TryGetAutodiscoverEndpointUrl;
    /**
     * Gets the enabled autodiscover endpoints on a specific host.
     *
     * @param   {host: IRefParam<string>}   host        The host.
     * @param   {IOutParam<AutodiscoverEndpoints>}   endpoints   Endpoints found for host.
     */
    private TryGetEnabledEndpointsForHost;
    ThrowIfDuplicateRedirection(emailAddress: string, redirectionEmailAddresses: IRefParam<string[]>): void;
    /**
     * Tries the get redirection response.
     *
     * @param   {XMLHttpRequest}  response      The response.
     * @param   {IOutParam<Uri>}  redirectUrl   The redirect URL.
     * @return  {boolean}         True if a valid redirection URL was found.
     */
    private TryGetRedirectionResponse;
}
export interface GetSettingsMethod<TGetSettingsResponseCollection, TSettingName> {
    (smtpAddresses: string[], settings: TSettingName[], requestedVersion: ExchangeVersion, autodiscoverUrl: IRefParam<Uri>): Promise<TGetSettingsResponseCollection>;
}
