import { Dictionary } from "../AltDictionary";
import { ExchangeCredentials } from "../Credentials/ExchangeCredentials";
import { ExchangeServerInfo } from "./ExchangeServerInfo";
import { ExchangeVersion } from "../Enumerations/ExchangeVersion";
import { ITraceListener } from "../Interfaces/ITraceListener";
import { IXHRApi } from "../Interfaces";
import { ResponseHeadersCapturedHandler, CustomXmlSerializationDelegate } from "../Misc/DelegateTypes";
import { TimeZoneInfo } from "../TimeZoneInfo";
import { TraceFlags } from "../Enumerations/TraceFlags";
/**
 * Represents an abstract binding to an Exchange Service.
 */
export declare abstract class ExchangeServiceBase {
    private readonly requestedServerVersion;
    /**
     * The binary secret.
     */
    private static binarySecret;
    /**
     * Default UserAgent
     */
    private static defaultUserAgent;
    OnResponseHeadersCaptured: ResponseHeadersCapturedHandler;
    private credentials;
    private timeout;
    private traceEnabled;
    private sendClientLatencies;
    private traceFlags;
    private traceListener;
    private preAuthenticate;
    private userAgent;
    private acceptGzipEncoding;
    private keepAlive;
    private connectionGroupName;
    private clientRequestId;
    private returnClientRequestId;
    protected timeZone: TimeZoneInfo;
    private timeZoneDefinition;
    private serverInfo;
    private httpHeaders;
    private httpResponseHeaders;
    private suppressXmlVersionHeader;
    /**
     * Provides an event that applications can implement to emit custom SOAP headers in requests that are sent to Exchange.
     * @event
     */
    OnSerializeCustomSoapHeaders: CustomXmlSerializationDelegate;
    /**
     * Gets or sets a value indicating whether client latency info is push to server.
     */
    get SendClientLatencies(): boolean;
    set SendClientLatencies(value: boolean);
    /**
     * Gets or sets a value indicating whether tracing is enabled.
     */
    get TraceEnabled(): boolean;
    set TraceEnabled(value: boolean);
    /**
     * Gets or sets the trace flags.
     */
    get TraceFlags(): TraceFlags;
    set TraceFlags(value: TraceFlags);
    /**
     * Gets or sets the trace listener.
     */
    get TraceListener(): ITraceListener;
    set TraceListener(value: ITraceListener);
    /**
     * Gets or sets the credentials used to authenticate with the Exchange Web Services. Setting the Credentials property automatically sets the UseDefaultCredentials to false.
     */
    get Credentials(): ExchangeCredentials;
    set Credentials(value: ExchangeCredentials);
    /**
     * Gets or sets the timeout used when sending HTTP requests and when receiving HTTP responses, in milliseconds. Defaults to 100000.
     */
    get Timeout(): number;
    set Timeout(value: number);
    /**
     * Gets or sets a value that indicates whether HTTP pre-authentication should be performed.
     */
    get PreAuthenticate(): boolean;
    set PreAuthenticate(value: boolean);
    /**
     * Gets or sets a value indicating whether GZip compression encoding should be accepted.
     * @remarks This value will tell the server that the client is able to handle GZip compression encoding. The server will only send Gzip compressed content if it has been configured to do so.
     * @remarks {ewsjs} not used in ewsjs
     */
    get AcceptGzipEncoding(): boolean;
    set AcceptGzipEncoding(value: boolean);
    /**
     * Gets the requested server version.
     */
    get RequestedServerVersion(): ExchangeVersion;
    /**
     * Gets or sets the user agent.
     */
    get UserAgent(): string;
    set UserAgent(value: string);
    /**
     * Gets information associated with the server that processed the last request. Will be null if no requests have been processed.
     */
    get ServerInfo(): ExchangeServerInfo;
    /**
     * Gets or sets if the request to the internet resource should contain a Connection HTTP header with the value Keep-alive
     */
    get KeepAlive(): boolean;
    set KeepAlive(value: boolean);
    /**
     * Gets or sets the name of the connection group for the request.
     */
    get ConnectionGroupName(): string;
    set ConnectionGroupName(value: string);
    /**
     * Gets or sets the request id for the request.
     */
    get ClientRequestId(): string;
    set ClientRequestId(value: string);
    /**
     * Gets or sets a flag to indicate whether the client requires the server side to return the  request id.
     */
    get ReturnClientRequestId(): boolean;
    set ReturnClientRequestId(value: boolean);
    /**
     * Gets a collection of HTTP headers that will be sent with each request to EWS.
     */
    get HttpHeaders(): Dictionary<string, string>;
    /**
     * Gets a collection of HTTP headers from the last response.
     */
    get HttpResponseHeaders(): Dictionary<string, string>;
    set SuppressXmlVersionHeader(value: boolean);
    private xhrApi;
    get XHRApi(): IXHRApi;
    set XHRApi(xhrApi: IXHRApi);
    /**
     * Initializes a new instance of the **ExchangeServiceBase** class.
     *
     */
    constructor();
    /**
     * Initializes a new instance of the **ExchangeServiceBase** class.
     *
     * @param   {TimeZoneInfo}   timeZone   The time zone to which the service is scoped.
     */
    constructor(timeZone: TimeZoneInfo);
    /**
     * Initializes a new instance of the **ExchangeServiceBase** class.
     *
     * @param   {ExchangeVersion}   requestedServerVersion   The requested server version.
     */
    constructor(requestedServerVersion: ExchangeVersion);
    /**
     * Initializes a new instance of the **ExchangeServiceBase** class.
     *
     * @param   {ExchangeVersion}   requestedServerVersion   The requested server version.
     * @param   {TimeZoneInfo}      timeZone                 The time zone to which the service is scoped.
     */
    constructor(requestedServerVersion: ExchangeVersion, timeZone: TimeZoneInfo);
    /**
     * Save the HTTP response headers.
     *
     * @param   {Object}   response   The response headers
     */
    private SaveHttpResponseHeaders;
    /**
     * Traces the HTTP response headers.
     *
     * @param   {TraceFlags}   traceType   Kind of trace entry.
     * @param   {XMLHttpRequest}   response    The response.
     */
    private TraceHttpResponseHeaders;
}
