import { BasePropertySet } from "../Enumerations/BasePropertySet";
import { BodyType } from "../Enumerations/BodyType";
import { Dictionary } from "../AltDictionary";
import { IEnumerable } from "../Interfaces/IEnumerable";
import { ISelfValidate } from "../Interfaces/ISelfValidate";
import { LazyMember } from "./LazyMember";
import { PropertyDefinitionBase } from "../PropertyDefinitions/PropertyDefinitionBase";
export type DefaultPropertySetDictionary = LazyMember<Dictionary<BasePropertySet, string>>;
/**
 * Represents a set of item or folder properties. Property sets are used to indicate what properties of an item or folder should be loaded when binding to an existing item or folder or when loading an item or folder's properties.
 *
 * @sealed
 */
export declare class PropertySet implements ISelfValidate, IEnumerable<PropertyDefinitionBase> {
    /**
     * Returns a predefined property set that only includes the Id property.
     */
    static readonly IdOnly: PropertySet;
    /**
     * Returns a predefined property set that includes the first class properties of an item or folder.
     */
    static readonly FirstClassProperties: PropertySet;
    /**
     * Maps BasePropertySet values to EWS's BaseShape values.
     */
    private static defaultPropertySetMap;
    /**
     * The base property set this property set is based upon.
     */
    private basePropertySet;
    /**
     * The list of additional properties included in this property set.
     */
    private additionalProperties;
    /**
     * The requested body type for get and find operations. If null, the "best body" is returned.
     */
    private requestedBodyType;
    /**
     * The requested unique body type for get and find operations. If null, the should return the same value as body type.
     */
    private requestedUniqueBodyType;
    /**
     * The requested normalized body type for get and find operations. If null, the should return the same value as body type.
     */
    private requestedNormalizedBodyType;
    /**
     * Value indicating whether or not the server should filter HTML content.
     */
    private filterHtml;
    /**
     * Value indicating whether or not the server should convert HTML code page to UTF8.
     */
    private convertHtmlCodePageToUTF8;
    /**
     * Value of the URL template to use for the src attribute of inline IMG elements.
     */
    private inlineImageUrlTemplate;
    /**
     * Value indicating whether or not the server should block references to external images.
     */
    private blockExternalImages;
    /**
     * Value indicating whether or not to add a blank target attribute to anchor links.
     */
    private addTargetToLinks;
    /**
     * Value indicating whether or not this PropertySet can be modified.
     */
    private isReadOnly;
    /**
     * Value indicating the maximum body size to retrieve.
     */
    private maximumBodySize;
    /**
     * Gets or sets the base property set the property set is based upon.
     */
    get BasePropertySet(): BasePropertySet;
    set BasePropertySet(value: BasePropertySet);
    /**
     * Gets or sets type of body that should be loaded on items. If RequestedBodyType is null, body is returned as HTML if available, plain text otherwise.
     *
     * @Nullable
     */
    get RequestedBodyType(): BodyType;
    set RequestedBodyType(value: BodyType);
    /**
     * Gets or sets type of body that should be loaded on items. If null, the should return the same value as body type.
     *
     * @nullable
     */
    get RequestedUniqueBodyType(): BodyType;
    set RequestedUniqueBodyType(value: BodyType);
    /**
     * Gets or sets type of normalized body that should be loaded on items. If null, the should return the same value as body type.
     *
     * @nullable
     */
    get RequestedNormalizedBodyType(): BodyType;
    set RequestedNormalizedBodyType(value: BodyType);
    /**
     * Gets the number of explicitly added properties in this set.
     */
    get Count(): number;
    /**
     * Gets or sets value indicating whether or not to filter potentially unsafe HTML content from message bodies.
     *
     * @nullable
     */
    get FilterHtmlContent(): boolean;
    set FilterHtmlContent(value: boolean);
    /**
     * Gets or sets value indicating whether or not to convert HTML code page to UTF8 encoding.
     *
     * @nullable
     */
    get ConvertHtmlCodePageToUTF8(): boolean;
    set ConvertHtmlCodePageToUTF8(value: boolean);
    /**
     * Gets or sets a value of the URL template to use for the src attribute of inline IMG elements.
     *
     * @nullable
     */
    get InlineImageUrlTemplate(): string;
    set InlineImageUrlTemplate(value: string);
    /**
     * Gets or sets value indicating whether or not to convert inline images to data URLs.
     *
     * @nullable
     */
    get BlockExternalImages(): boolean;
    set BlockExternalImages(value: boolean);
    /**
     * Gets or sets value indicating whether or not to add blank target attribute to anchor links.
     *
     * @nullable
     */
    get AddBlankTargetToLinks(): boolean;
    set AddBlankTargetToLinks(value: boolean);
    /**
     * Gets or sets the maximum size of the body to be retrieved.
     *
     * @nullable
     *
     * @value   The maximum size of the body to be retrieved.
     */
    get MaximumBodySize(): number;
    set MaximumBodySize(value: number);
    /**
     * Initializes a new instance of **PropertySet** based upon BasePropertySet.IdOnly.
     */
    constructor();
    /**
     * Initializes a new instance of **PropertySet** based upon BasePropertySet.IdOnly.
     *
     * @param   {BasePropertySet}   basePropertySet        The base property set to base the property set upon.
     */
    constructor(basePropertySet: BasePropertySet);
    /**
     * Initializes a new instance of **PropertySet** based upon BasePropertySet.IdOnly.
     *
     * @param   {PropertyDefinitionBase[]}  additionalProperties   Additional properties to include in the property set. Property definitions are available as static members from schema classes (for example, EmailMessageSchema.Subject, AppointmentSchema.Start, ContactSchema.GivenName, etc.)
     */
    constructor(additionalProperties: PropertyDefinitionBase[]);
    /**
     * Initializes a new instance of **PropertySet**.
     *
     * @param   {PropertyDefinitionBase[]}  additionalProperties   Additional properties to include in the property set. Property definitions are available as static members from schema classes (for example, EmailMessageSchema.Subject, AppointmentSchema.Start, ContactSchema.GivenName, etc.)
     */
    constructor(...additionalProperties: PropertyDefinitionBase[]);
    /**
     * Initializes a new instance of **PropertySet**.
     *
     * @param   {BasePropertySet}           basePropertySet        The base property set to base the property set upon.
     * @param   {PropertyDefinitionBase[]}  additionalProperties   Additional properties to include in the property set. Property definitions are available as static members from schema classes (for example, EmailMessageSchema.Subject, AppointmentSchema.Start, ContactSchema.GivenName, etc.)
     */
    constructor(basePropertySet: BasePropertySet, additionalProperties: PropertyDefinitionBase[]);
    /**
     * Initializes a new instance of **PropertySet**.
     *
     * @param   {BasePropertySet}           basePropertySet        The base property set to base the property set upon.
     * @param   {PropertyDefinitionBase[]}  additionalProperties   Additional properties to include in the property set. Property definitions are available as static members from schema classes (for example, EmailMessageSchema.Subject, AppointmentSchema.Start, ContactSchema.GivenName, etc.)
     */
    constructor(basePropertySet: BasePropertySet, ...additionalProperties: PropertyDefinitionBase[]);
    /**
     * Gets the **PropertyDefinitionBase** at the specified index. this[int] indexer
     *
     * @param   {number}   index   Index.
     */
    _getItem(index: number): PropertyDefinitionBase;
    /**
     * Adds the specified property to the property set.
     *
     * @param   {PropertyDefinitionBase}   property   The property to add.
     */
    Add(property: PropertyDefinitionBase): void;
    /**
     * Adds the specified properties to the property set.
     *
     * @param   {PropertyDefinitionBase[]}   properties   The properties to add.
     */
    AddRange(properties: PropertyDefinitionBase[]): void;
    /**
     * Remove all explicitly added properties from the property set.
     */
    Clear(): void;
    /**
     * Determines whether the specified property has been explicitly added to this property set using the Add or AddRange methods.
     *
     * @param   {PropertyDefinitionBase}    property   The property.
     * @return  {boolean}                   true if this property set contains the specified propert]; otherwise, false.
     */
    Contains(property: PropertyDefinitionBase): boolean;
    /**
     * Creates a read-only PropertySet.
     *
     * @param   {BasePropertySet}   basePropertySet   The base property set.
     * @return  {PropertySet}       PropertySet
     */
    private static CreateReadonlyPropertySet;
    /**
     *  Returns an enumerator that iterates through the collection. this case this.additionalProperties itself
     */
    GetEnumerator(): PropertyDefinitionBase[];
    /**
     * Gets the name of the shape.
     *
     * @param   {ServiceObjectType}     serviceObjectType   Type of the service object.
     * @return  {string}                Shape name.
     */
    private static GetShapeName;
    /**
     * Removes the specified property from the set.
     *
     * @param   {PropertyDefinitionBase}    property   The property to remove.
     * @return  {boolean}                   true if the property was successfully removed, false otherwise.
     */
    Remove(property: PropertyDefinitionBase): boolean;
    /**
     * Throws if readonly property set.
     */
    private ThrowIfReadonly;
    /**
     * Implements ISelfValidate.Validate. Validates this property set.
     */
    Validate(): void;
}
