import { ConflictResolutionMode } from '../../../Enumerations/ConflictResolutionMode';
import { DateTime } from '../../../DateTime';
import { DeleteMode } from '../../../Enumerations/DeleteMode';
import { ExchangeService } from '../../ExchangeService';
import { ItemId } from '../../../ComplexProperties/ItemId';
import { PropertySet } from '../../PropertySet';
import { Recurrence } from '../../../ComplexProperties/Recurrence/Patterns/Recurrence';
import { StringList } from '../../../ComplexProperties/StringList';
import { TaskDelegationState } from '../../../Enumerations/TaskDelegationState';
import { TaskMode } from '../../../Enumerations/TaskMode';
import { TaskStatus } from '../../../Enumerations/TaskStatus';
import { Item } from './Item';
/**
 * Represents a Task item. Properties available on tasks are defined in the TaskSchema class.
 */
export declare class Task extends Item {
    /** required to check [Attachable] attribute, AttachmentCollection.AddItemAttachment<TItem>() checks for non inherited [Attachable] attribute. */
    static get Attachable(): boolean;
    /**
     * @nullable Gets or sets the actual amount of time that is spent on the task.
     */
    get ActualWork(): number;
    set ActualWork(value: number);
    /**
     * @nullable Gets the date and time the task was assigned.
     */
    get AssignedTime(): DateTime;
    /**
     * Gets or sets the billing information of the task.
     */
    get BillingInformation(): string;
    set BillingInformation(value: string);
    /**
     * Gets the number of times the task has changed since it was created.
     */
    get ChangeCount(): number;
    /**
     * Gets or sets a list of companies associated with the task.
     */
    get Companies(): StringList;
    set Companies(value: StringList);
    /**
     * @nullable Gets or sets the date and time on which the task was completed.
     */
    get CompleteDate(): DateTime;
    set CompleteDate(value: DateTime);
    /**
     * Gets or sets a list of contacts associated with the task.
     */
    get Contacts(): StringList;
    set Contacts(value: StringList);
    /**
     * Gets the current delegation state of the task.
     */
    get DelegationState(): TaskDelegationState;
    /**
     * Gets the name of the delegator of this task.
     */
    get Delegator(): string;
    /**
     * @nullable    Gets or sets the date and time on which the task is due.
     */
    get DueDate(): DateTime;
    set DueDate(value: DateTime);
    /**
     * Gets a value indicating the mode of the task.
     */
    get Mode(): TaskMode;
    /**
     * Gets a value indicating whether the task is complete.
     */
    get IsComplete(): boolean;
    /**
     * Gets a value indicating whether the task is recurring.
     */
    get IsRecurring(): boolean;
    /**
     * Gets a value indicating whether the task is a team task.
     */
    get IsTeamTask(): boolean;
    /**
     * Gets or sets the mileage of the task.
     */
    get Mileage(): string;
    set Mileage(value: string);
    /**
     * Gets the name of the owner of the task.
     */
    get Owner(): string;
    /**
     * Gets or sets the completeion percentage of the task. PercentComplete must be between 0 and 100.
     */
    get PercentComplete(): number;
    set PercentComplete(value: number);
    /**
     * Gets or sets the recurrence pattern for this task. Available recurrence pattern classes include Recurrence.
     * DailyPattern, Recurrence.MonthlyPattern and Recurrence.YearlyPattern.
     */
    get Recurrence(): Recurrence;
    set Recurrence(value: Recurrence);
    /**
     * @nullable    Gets or sets the date and time on which the task starts.
     */
    get StartDate(): DateTime;
    set StartDate(value: DateTime);
    /**
     * Gets or sets the status of the task.
     */
    get Status(): TaskStatus;
    set Status(value: TaskStatus);
    /**
     * Gets a string representing the status of the task, localized according to the PreferredCulture property of the ExchangeService object the task is bound to.
     */
    get StatusDescription(): string;
    /**
     * @nullable Gets or sets the total amount of work spent on the task.
     */
    get TotalWork(): number;
    set TotalWork(value: number);
    /**
     * Initializes an unsaved local instance of **Task**. To bind to an existing task, use Task.Bind() instead.
     *
     * @param   {ExchangeService}   service   The ExchangeService instance to which this task is bound.
     */
    constructor(service: ExchangeService);
    /**
     * Binds to an existing task and loads the specified set of properties.
     * Calling this method results in a call to EWS.
     *
     * @param   {ExchangeService}   service       The service to use to bind to the task.
     * @param   {ItemId}            id            The Id of the task to bind to.
     * @param   {PropertySet}       propertySet   The set of properties to load.
     * @return  {Promise<Task>}    A Task instance representing the task corresponding to the specified Id :Promise.
     */
    static Bind(service: ExchangeService, id: ItemId, propertySet: PropertySet): Promise<Task>;
    /**
     * Binds to an existing task and loads its first class properties.
     * Calling this method results in a call to EWS.
     *
     * @param   {ExchangeService}   service       The service to use to bind to the task.
     * @param   {ItemId}            id            The Id of the task to bind to.
     * @return  {Promise<Task>}    A Task instance representing the task corresponding to the specified Id :Promise.
     */
    static Bind(service: ExchangeService, id: ItemId): Promise<Task>;
    /**
     * Deletes the current occurrence of a recurring task. After the current occurrence isdeleted, the task represents the next occurrence.
     * Developers should call Load to retrieve the new property values of the task.
     * Calling this method results in a call to EWS.
     *
     * @param   {DeleteMode}   deleteMode   The deletion mode.
     * @return  {Promise<void>}            :Promise.
     */
    DeleteCurrentOccurrence(deleteMode: DeleteMode): Promise<void>;
    /**
     * Applies the local changes that have been made to this task. Calling this method results in at least one call to EWS.
     * Mutliple calls to EWS might be made if attachments have been added or removed.
     *
     * @param   {ConflictResolutionMode}    conflictResolutionMode   Specifies how conflicts should be resolved.
     * @return  {Promise<Task>}            A Task object representing the completed occurrence if the task is recurring and the update marks it as completed; or a Task object representing the current occurrence if the task is recurring and the uypdate changed its recurrence pattern; or null in every other case    :Promise.
     */
    Update(conflictResolutionMode: ConflictResolutionMode): Promise<Task>;
    /** ##internal ~~ workaround GitHub #52 */
    Update(conflictResolutionMode: ConflictResolutionMode): Promise<any>;
}
